#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xos.h>
#include <stdio.h>
#include "bounce.h"

#define Plot(x,y)	XDrawPoint(display,win,gc,(x),(y))
#define Line(x1,y1,x2,y2)	XDrawLine(display,win,gc,(x1),(y1),(x2),(y2))

Display *display;
Window win; 
GC gc;
int screen;
Pixmap pm;
XImage *image;

#include "x_image.h"

void open_window()
{
	char *window_name = "Bounce Window";
	char *display_name = NULL;
	XSizeHints size_hints;
	XWindowAttributes attr;
	int depth;

	if ((display = XOpenDisplay(display_name)) == NULL)
	{
		(void)fprintf(stderr, "%s: cannot connect to X server %s\n", 
					XDisplayName(display_name));
		exit(-1);
	}

	screen = DefaultScreen(display);
	
	win = XCreateSimpleWindow(display, RootWindow(display, screen), 
								WIDTH, HEIGHT, WIDTH, HEIGHT, 0, 
								BlackPixel(display, screen), 
								WhitePixel(display, screen));

	XGetWindowAttributes(display, win, &attr);
	depth = attr.depth;

	size_hints.flags = PPosition|PSize|PMaxSize|PMinSize;
	size_hints.x = WX; size_hints.y = WY;
	size_hints.width = WIDTH; size_hints.height = HEIGHT;
	size_hints.min_width = WIDTH; size_hints.min_height = HEIGHT;

	XSetStandardProperties(display, win, window_name, NULL, 
							NULL, NULL, NULL, &size_hints);

	gc = XCreateGC(display, win, 0, NULL);
	XSetForeground(display, gc, BlackPixel(display, screen));
	XSetBackground(display, gc, WhitePixel(display, screen));
	XSetPlaneMask(display, gc, 
		BlackPixel(display,screen)^WhitePixel(display,screen));

	XMapWindow(display, win);

	pm = XCreatePixmapFromBitmapData(display, win, icon_image, IWIDTH, IHEIGHT, 
				BlackPixel(display, screen), WhitePixel(display, screen),depth);
	
	image = XGetImage(display, pm, 0, 0, IWIDTH, IHEIGHT, AllPlanes, ZPixmap);

	XFlush(display);
	XSync(display, 0);
	sleep(1);
}

void close_window()
{
	XFreeGC(display, gc);
	XCloseDisplay(display);
}

void draw(x, y)
int x, y;
{
	XSetFunction(display, gc, GXcopy);
	XPutImage(display, win, gc, image, 0, 0, x, y, IWIDTH, IHEIGHT);
	XFlush(display);
}

void draw_inverted(x, y)
int x, y;
{
	XSetFunction(display, gc, GXcopyInverted);
	XPutImage(display, win, gc, image, 0, 0, x, y, IWIDTH, IHEIGHT);
	XFlush(display);
}

void clear()
{
	XFillRectangle(display, win, gc, 0, 0, WIDTH, HEIGHT);
}
